@@ -5,7 +5,7 @@ use warnings;
 package Log::Any;
 
 # ABSTRACT: Bringing loggers and listeners together
-our $VERSION = '1.713';
+our $VERSION = '1.718';
 
 use Log::Any::Manager;
 use Log::Any::Proxy::Null;
@@ -135,7 +135,7 @@ Log::Any - Bringing loggers and listeners together
 
 =head1 VERSION
 
-version 1.713
+version 1.718
 
 =head1 SYNOPSIS
 
@@ -478,7 +478,7 @@ Stephen Thirlwall <sdt@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Andrew Grechkin bj5004 cm-perl Doug Bell Jonathan Karen Etheridge Konstantin S. Uvarin Larry Leszczynski Lucas Kanashiro Maros Kollar Maxim Vuets mephinet Michael Conrad Nick Tonkin Paul Durden Philipp Gortan Phill Legault Shlomi Fish Sven Willenbuecher XSven
+=for stopwords Andrew Grechkin Hewus Fresh bj5004 cm-perl Jonathan Rubin Karen Etheridge Konstantin S. Uvarin Larry Leszczynski Lucas Kanashiro Maros Kollar Maxim Vuets mephinet Michael Conrad Nick Tonkin Paul Durden Philipp Gortan Phill Legault Samuel Ng Shlomi Fish Sven Willenbuecher XSven
 
 =over 4
 
@@ -488,6 +488,10 @@ Andrew Grechkin <andrew.grechkin@gmail.com>
 
 =item *
 
+Andrew Hewus Fresh <andrew+github@afresh1.com>
+
+=item *
+
 bj5004 <bartosz.jakubski@hurra.com>
 
 =item *
@@ -496,11 +500,11 @@ cm-perl <cm-perl@users.noreply.github.com>
 
 =item *
 
-Doug Bell <preaction@users.noreply.github.com>
+Jonathan <jjrs.pam+github@gmail.com>
 
 =item *
 
-Jonathan <jjrs.pam+github@gmail.com>
+Jonathan Rubin <jon.rubin@grantstreet.com>
 
 =item *
 
@@ -552,6 +556,10 @@ Phill Legault <saladdayllc@gmail.com>
 
 =item *
 
+Samuel Ng <samuel.ng@grantstreet.com>
+
+=item *
+
 Shlomi Fish <shlomif@shlomifish.org>
 
 =item *
